@@ -1,9 +1,11 @@
 import pymongo
 
-from fixtures import TempDir
-
-from txfixtures.service import Service
+from txfixtures.service import (
+    TIMEOUT,
+    Service
+)
 
+COMMAND = b"mongod"
 FORMAT = (
     "{Y}-{m}-{d}T{H}:{M}:{S}\.{msecs}\+0000 {levelname} "
     "[A-Z]+ +\[{name}\] {message}")
@@ -12,9 +14,8 @@ FORMAT = (
 class MongoDB(Service):
     """Start and stop a `mongodb` process in the background. """
 
-    def __init__(self, mongod=b"mongod", args=(), **kwargs):
-        command = [mongod] + list(args)
-        super(MongoDB, self).__init__(command, **kwargs)
+    def __init__(self, reactor, timeout=TIMEOUT):
+        super(MongoDB, self).__init__(reactor, COMMAND, timeout=timeout)
 
         self.expectOutput("waiting for connections on port")
         self.setOutputFormat(FORMAT)
@@ -30,7 +31,7 @@ class MongoDB(Service):
 
     def _setUp(self):
         self.expectPort(self.allocatePort())
-        self._dbPath = self.useFixture(TempDir())
+        self.addDataDir()
         super(MongoDB, self)._setUp()
         uri = "mongodb://localhost:%d" % self.port
         self.client = pymongo.MongoClient(uri, **self.clientKwargs)
@@ -41,8 +42,8 @@ class MongoDB(Service):
 
     @property
     def _args(self):
-        return self.command[:] + [
+        return [self.command] + [
             b"--port=%d" % self.port,
-            b"--dbpath=%s" % self._dbPath.path.encode("utf-8"),
+            b"--dbpath=%s" % self._data_dirs[0].encode("utf-8"),
             b"--nojournal",
         ]
