@@ -1,10 +1,14 @@
+import os
+
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from selenium.webdriver.remote import webdriver
 
-from fixtures import TempDir
-
-from txfixtures.service import Service
+from txfixtures.service import (
+    TIMEOUT,
+    Service,
+)
 
+COMMAND = b"phantomjs"
 FORMAT = (
     "\[{levelname} +- +{Y}-{m}-{d}T{H}:{M}:{S}\.{msecs}Z\] {name} - {message}")
 
@@ -12,9 +16,8 @@ FORMAT = (
 class PhantomJS(Service):
     """Start and stop a `phantomjs` process in the background. """
 
-    def __init__(self, phantomjs="phantomjs", args=(), **kwargs):
-        command = [phantomjs] + list(args)
-        super(PhantomJS, self).__init__(command, **kwargs)
+    def __init__(self, reactor, timeout=TIMEOUT):
+        super(PhantomJS, self).__init__(reactor, COMMAND, timeout=timeout)
 
         #: Desired capabilities that will be passed to the webdriver.
         self.desiredCapabilities = DesiredCapabilities.PHANTOMJS
@@ -28,7 +31,7 @@ class PhantomJS(Service):
 
     def _setUp(self):
         self.expectPort(self.allocatePort())
-        self._cookies = self.useFixture(TempDir()).join("phantomjs.cookies")
+        self.addDataDir()
         super(PhantomJS, self)._setUp()
         url = "http://localhost:%d/wd/hub" % self.protocol.expectedPort
         self.webdriver = webdriver.WebDriver(
@@ -37,7 +40,8 @@ class PhantomJS(Service):
 
     @property
     def _args(self):
-        return self.command[:] + [
+        cookies_file = os.path.join(self._data_dirs[0], "phantomjs.cookies")
+        return [self.command] + [
             "--webdriver=%d" % self.protocol.expectedPort,
-            "--cookies-file=%s" % self._cookies,
+            "--cookies-file=%s" % cookies_file,
         ]
